@@ -1,20 +1,44 @@
-# lib/Software/License/GPL_3/or_later.pm #
+# lib/Software/License/or_later.pm #
 
-#   This file is part of Software-License-OrLaterPack.
-#
-#   Software-License-OrLaterPack is free software: you can redistribute it
-#   and/or modify it under the terms of the GNU General Public License as
-#   published by the Free Software Foundation, either version 3 of the
-#   License, or (at your option) any later version.
-#
-#   Software-License-OrLaterPack is distributed in the hope that it will be
-#   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-#   Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License along
-#   with Software-License-OrLaterPack.  If not, see
-#   <http://www.gnu.org/licenses/>.
+#pod =encoding UTF-8
+#pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright © 2015 Van de Bugger
+#pod
+#pod This file is part of Software-License-OrLaterPack.
+#pod
+#pod Software-License-OrLaterPack is free software: you can redistribute it and/or modify it under the
+#pod terms of the GNU General Public License as published by the Free Software Foundation, either
+#pod version 3 of the License, or (at your option) any later version.
+#pod
+#pod Software-License-OrLaterPack is distributed in the hope that it will be useful, but WITHOUT ANY
+#pod WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+#pod See the GNU General Public License for more details.
+#pod
+#pod You should have received a copy of the GNU General Public License along with
+#pod Software-License-OrLaterPack. If not, see <http://www.gnu.org/licenses/>.
+#pod
+#pod =cut
+
+#pod =head1 DESCRIPTION
+#pod
+#pod Look into L<Software::License::OrLaterPack> for general topics: purpose, installation, etc.
+#pod
+#pod C<Software::License::GPL_3::or_later> is a subclass of L<Software::License::GPL_3>.
+#pod It overrides few parent methods:
+#pod
+#pod =for :list
+#pod = C<name>
+#pod appends ", or any later" clause to the parent license name;
+#pod = C<version>
+#pod appends "+" to the parent license version;
+#pod = C<notice>
+#pod returns copyright statement and standard GNU 3-paragraph license notice.
+#pod
+#pod See documentation on L<Software::License> for a general description of the class interface.
+#pod
+#pod =cut
 
 package Software::License::GPL_3::or_later;
 
@@ -23,9 +47,9 @@ package Software::License::GPL_3::or_later;
 use strict;
 use warnings;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
-use parent __PACKAGE__ =~ m{\A(.*)::or_later\z};
+use parent 'Software::License::GPL_3';
 use Text::Wrap;
 
 #pod =method _name
@@ -72,7 +96,7 @@ sub version { $_[ 0 ]->_version . '+'; };
 #pod * The method has optional parameter — program name (default name is "this program"). It is used in
 #pod notice text.
 #pod * It returns copyright statement followed by standard GNU 3-paragraph license notice.
-#pod * Result is formatted with `Text::Wrap::fill`.
+#pod * Result is formatted with L<Text::Wrap::fill>.
 #pod
 #pod B<Note:> Program name is an experimental feature.
 #pod
@@ -90,26 +114,6 @@ sub notice {
 
 1;
 
-#pod =pod
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod C<Software::License::GPL_3::or_later> is a subclass of L<Software::License::GPL_3>. It overrides
-#pod few parent methods:
-#pod
-#pod =for :list
-#pod = C<name>
-#pod appends ", or any later" clause to the parent license name;
-#pod = C<version>
-#pod appends "+" to the parent license version;
-#pod = C<notice>
-#pod returns copyright statement and standard GNU 3-paragraph license notice (see the section
-#pod L<COPYRIGHT AND LICENSE> below).
-#pod
-#pod See documentation on L<Software::License> for a general description of class interface.
-#pod
-#pod =cut
-
 =pod
 
 =encoding UTF-8
@@ -120,12 +124,14 @@ Software::License::GPL_3::or_later - GPLv3+ license for Software::License
 
 =head1 VERSION
 
-version 0.006
+Version 0.007.
 
 =head1 DESCRIPTION
 
-C<Software::License::GPL_3::or_later> is a subclass of L<Software::License::GPL_3>. It overrides
-few parent methods:
+Look into L<Software::License::OrLaterPack> for general topics: purpose, installation, etc.
+
+C<Software::License::GPL_3::or_later> is a subclass of L<Software::License::GPL_3>.
+It overrides few parent methods:
 
 =over 4
 
@@ -139,12 +145,11 @@ appends "+" to the parent license version;
 
 =item C<notice>
 
-returns copyright statement and standard GNU 3-paragraph license notice (see the section
-L<COPYRIGHT AND LICENSE> below).
+returns copyright statement and standard GNU 3-paragraph license notice.
 
 =back
 
-See documentation on L<Software::License> for a general description of class interface.
+See documentation on L<Software::License> for a general description of the class interface.
 
 =head1 METHODS
 
@@ -184,7 +189,7 @@ It returns copyright statement followed by standard GNU 3-paragraph license noti
 
 =item *
 
-Result is formatted with `Text::Wrap::fill`.
+Result is formatted with L<Text::Wrap::fill>.
 
 =back
 
@@ -196,23 +201,25 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Van de Bugger
+Copyright © 2015 Van de Bugger
 
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation, either version 3 of the License, or (at your option) any later
-version.
+This file is part of Software-License-OrLaterPack.
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+Software-License-OrLaterPack is free software: you can redistribute it and/or modify it under the
+terms of the GNU General Public License as published by the Free Software Foundation, either
+version 3 of the License, or (at your option) any later version.
+
+Software-License-OrLaterPack is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
-this program.  If not, see <http://www.gnu.org/licenses/>.
+Software-License-OrLaterPack. If not, see <http://www.gnu.org/licenses/>.
 
 =cut
 
 __DATA__
+
 __NOTICE__
 Copyright (C) {{ $self->year }} {{ $self->holder }}
 
@@ -220,13 +227,13 @@ Copyright (C) {{ $self->year }} {{ $self->holder }}
 under the terms of {{ $self->_name }} as published by the Free Software Foundation, either version
 {{ $self->_version }} of the License, or (at your option) any later version.
 
-{{ ucfirst( $self->{ program } ) }} is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See {{ $self->_name }} for more details.
+{{ ucfirst( $self->{ program } ) }} is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE. See {{ $self->_name }} for more details.
 
 You should have received a copy of {{ $self->_name }} along with {{ $self->{ program } }}. If not,
 see <http://www.gnu.org/licenses/>.
-
 __END__
 
 # end of file #
+
